build_bbox_filter: Builds a filter to be used with getFeatures, that will filter...

View source: R/ows4r_utils.R

build_bbox_filterR Documentation

Builds a filter to be used with getFeatures, that will filter based on the given bounding box.

Description

Builds a filter to be used with getFeatures, that will filter based on the given bounding box.

Usage

build_bbox_filter(bbox)

Arguments

bbox

A matrix representing a bounding box.

Value

The character string of the filter.


malariaAtlas documentation built on March 28, 2026, 1:08 a.m.