build_cql_filter: Builds a cql filter to be used with getFeatures, that will...

View source: R/ows4r_utils.R

build_cql_filterR Documentation

Builds a cql filter to be used with getFeatures, that will filter based on the given list of values.

Description

Builds a cql filter to be used with getFeatures, that will filter based on the given list of values.

Usage

build_cql_filter(attribute, values)

Arguments

attribute

A string representing the attribute to filter by

values

A character, or character list, representing one or more values

Value

The character string of the cql filter.


malariaAtlas documentation built on March 28, 2026, 1:08 a.m.