build_cql_time_filter: Builds a cql filter to be used with getFeatures, that will...

View source: R/ows4r_utils.R

build_cql_time_filterR Documentation

Builds a cql filter to be used with getFeatures, that will filter based on the time range provided by start_date and end_date.

Description

Builds a cql filter to be used with getFeatures, that will filter based on the time range provided by start_date and end_date.

Usage

build_cql_time_filter(start_date, end_date)

Arguments

start_date

A Date Object that is the lower bound on the time range (inclusive).

end_date

A Date Object that is the upper bound on the time range (exclusive).

Value

The character string of the cql filter.


malariaAtlas documentation built on March 28, 2026, 1:08 a.m.