download_rst: Download rasters from the MAP geoserver to a specifed...

View source: R/getRaster.R

download_rstR Documentation

Download rasters from the MAP geoserver to a specifed location. If file already exists it will read it instead.

Description

Download rasters from the MAP geoserver to a specifed location. If file already exists it will read it instead.

Usage

download_rst(dataset_id, extent, year, file_name, file_path)

Arguments

dataset_id

ID for dataset on MAP geoserver

extent

desired raster extent

year

desired year to download

file_name

file name (excluding extension) to save raster to

file_path

path to save raster to

Value

SpatRaster


malariaAtlas documentation built on March 28, 2026, 1:08 a.m.