Learn R Programming

malariaAtlas (version 1.5.0)

get_name_from_wfs_feature_type_id: Get the name from a wfs feature type id.

Description

Get the name from a wfs feature type id.

Usage

get_name_from_wfs_feature_type_id(id)

Value

A name of the dataset

Arguments

id

The ID to parse.