get_workspace_and_version_from_coverage_id: Get the workspace and version from a raster id.

View source: R/ows4r_utils.R

get_workspace_and_version_from_coverage_idR Documentation

Get the workspace and version from a raster id.

Description

Get the workspace and version from a raster id.

Usage

get_workspace_and_version_from_coverage_id(id)

Arguments

id

The ID to parse.

Value

A list with the workspace and version.


malariaAtlas documentation built on March 28, 2026, 1:08 a.m.