- sourcedata
by default this is "vector points", highlighting the dataset to be searched
- country
string containing name of desired country, e.g. c("Country1", "Country2", ...) (use one of country OR ISO OR continent, not combined)
- ISO
string containing ISO3 code for desired country, e.g. c("XXX", "YYY", ...) (use one of country OR ISO OR continent, not combined)
- continent
string containing name of continent for desired data, e.g. c("Continent1", "Continent2", ...)(use one of country OR ISO OR continent, not combined)
- full_results
By default this is FALSE meaning the function only gives a message outlining whether specified country is available, if full_results == TRUE, the function returns a named list outlining data availability.