Learn R Programming

malariaAtlas (version 1.0.1)

listPoints: List countries with available MAP Point data.

Description

listPoints lists all countries for which there are publicly visible datapoints in the MAP database required.

Usage

listPoints(printed = TRUE, sourcedata)

Value

listPoints returns a data.frame detailing the countries for which PR points are publicly available.

Arguments

printed

Should the list be printed to the console?

sourcedata

String contining desired dataset within the Malaria Atlas database to be searched, e.g "pr points" OR "vector points"

Examples

Run this code
# \donttest{
listPoints(sourcedata = "pr points")
listPoints(sourcedata = "vector points")
# }

Run the code above in your browser using DataLab