listShp returns a data.frame detailing the administrative units for which shapefiles are stored on the MAP geoserver.
Arguments
printed
Should the list be printed to the console?
admin_level
Specifies which administrative unit level for which to return available polygon shapefiles. A string vector including one or more of"admin0", "admin1", "admin2" OR "admin3". Default: c("admin0", "admin1")