powered by
listSpecies lists all species occurrence data available to download from the Malaria Atlas Project database.
listSpecies
listSpecies(printed = TRUE)
listSpecies returns a data.frame detailing the following information for each species available to download from the Malaria Atlas Project database.
species string detailing species
species
should the list be printed to the database.
# \donttest{ available_species <- listSpecies() # }
Run the code above in your browser using DataLab