malariaAtlas: An R interface to open-access malaria data, hosted by the...

malariaAtlasR Documentation

An R interface to open-access malaria data, hosted by the Malaria Atlas Project.

Description

malariaAtlas provides a suite of tools to allow you to download all publicly available PR points for a specified country (or ALL countries) as a dataframe within R.

malariaAtlas functions

  1. listAll - lists all countries for which there are publicly visible PR datapoints in the MAP database.

  2. is_available - checks whether the MAP database contains PR points for the specified country/countries.

  3. getPR - downloads all publicly available PR points for a specified country (or countries) and returns this as a dataframe.

Author(s)

Maintainer: Mauricio van den Berg mauricio.vandenberg@thekids.org.au

Authors:

Other contributors:

  • Nick Golding [contributor]

  • David Smith [contributor]

See Also

Useful links:


malariaAtlas documentation built on March 28, 2026, 1:08 a.m.