powered by
listPoints lists all countries for which there are publicly visible datapoints in the MAP database required.
listPoints
listPoints(printed = TRUE, sourcedata)
listPoints returns a data.frame detailing the countries for which PR points are publicly available.
Should the list be printed to the console?
String contining desired dataset within the Malaria Atlas database to be searched, e.g "pr points" OR "vector points"
"pr points"
"vector points"
# \donttest{ listPoints(sourcedata = "pr points") listPoints(sourcedata = "vector points") # }
Run the code above in your browser using DataLab