| malariaAtlas | R Documentation |
malariaAtlas provides a suite of tools to allow you to
download all publicly available PR points for a specified country
(or ALL countries) as a dataframe within R.
listAll - lists all countries for which there are publicly visible PR datapoints in the MAP database.
is_available - checks whether the MAP database contains PR points for the specified country/countries.
getPR - downloads all publicly available PR points for a specified country (or countries) and returns this as a dataframe.
Maintainer: Mauricio van den Berg mauricio.vandenberg@thekids.org.au
Authors:
Daniel Pfeffer daniel.pfeffer@uqconnect.edu.au (ORCID)
Tim Lucas timcdlucas@gmail.com (ORCID)
Daniel May (ORCID)
Suzanne Keddie (ORCID)
Jen Rozier (ORCID)
Oliver Watson (ORCID)
Harry Gibson (ORCID)
Other contributors:
Nick Golding [contributor]
David Smith [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.